import pandas as pd

from datetime import datetime, date

def remove_date_datetime(dt: date) -> date:
    """ Remove a date from a datetime. """
    dt = dt.replace(year=1, month=1, day=1)
    return dt


def remove_week_datetime(dt: date) -> date:
    """ Change dates to the following:
        01/01/01 for a Monday
        02/01/01 for a Tuesday
        03/01/01 for a Wednesday
        04/01/01 for a Thursday
        05/01/01 for a Friday
        06/01/01 for a Saturday
        07/01/01 for a Sunday """

    day = dt.today().weekday()
    dt = dt.replace(year=1, month=1, day=(day + 1))
    return dt


def ggLeap_str_to_datetime(string: str) -> date:
    date = datetime.strptime(string,
                             '%m/%d/%Y %I:%M:%S %p')
    return date


def read_csv(path: str) -> pd.DataFrame:
    """ Function to replace pandas.read_csv() because
    ggLeap data is screwy to start with so this function
    cleans the data and then loads it into a pandas
    dataframe """

    cleaning_functions = [fix_RemoveOffers]

    f = open(path, 'r')
    raw_rows = f.readlines()
    raw_rows = [row.split(',') for row in raw_rows]
    columns = raw_rows.pop(0)

    for f in cleaning_functions:
        raw_rows = f(raw_rows)

    cleaned_df = pd.DataFrame(raw_rows)
    cleaned_df.columns = columns
    return cleaned_df


def fix_RemoveOffers(raw_rows: list) -> list:
    """ If ggLeap returns records which have a 'RemoveOffer' action, then another 
    of the columns will have a comma in it meaning that reading it as a CSV doesn't work
    properly. This function fixes that """

    new_df_vals = []
    for row in raw_rows:
        if 'RemovedOffer' in row:
            index = row.index('RemovedOffer')
            offer_name = row[index + 1]
            reason = row[index + 2]

            new_val = offer_name + "; " + reason

            row.pop(index + 2)
            row.pop(index + 1)
            row.insert(index + 1, new_val)

        new_df_vals.append(row)

    return new_df_vals



from datetime import datetime

import pandas as pd

from . import helpers
from . import DataHandler


def remove_dates(df: pd.DataFrame) -> pd.DataFrame:
    """
    Remove dates from all datetimes in a dataframe
    """
    
    new_records = []
    for i in range(len(df)):
        current_record = df.loc[i]
        date_string = current_record["Date"]
        dt = helpers.ggLeap_str_to_datetime(date_string)
        new_dt = helpers.remove_date_datetime(dt)
        current_record["Date"] = new_dt
        new_records.append(current_record)

    return pd.DataFrame(new_records)


def remove_weeks(df: pd.DataFrame) -> pd.DataFrame:
    """ Remove all weeks from datetimes

        Change all dates in the DataFrame to the following:
        01/01/01 for a Monday
        02/01/01 for a Tuesday
        03/01/01 for a Wednesday
        04/01/01 for a Thursday
        05/01/01 for a Friday
        06/01/01 for a Saturday
        07/01/01 for a Sunday """

    new_records = []
    for i in range(len(df)):
        current_record = df.loc[i]
        date_string = current_record["Date"]
        dt = helpers.ggLeap_str_to_datetime(date_string)
        new_dt = helpers.remove_week_datetime(dt)
        current_record["Date"] = new_dt
        new_records.append(current_record)

    return pd.DataFrame(new_records)


def total_user_seconds(dh: DataHandler.DataHandler, 
                       username: str) -> int:
    """
    Iterate across all of a user's logins and logouts to calculate
    the total amount of time that they've spent logged in
    """
    pass


def total_user_seconds_between(dh: DataHandler.DataHandler, 
                               username: str,
                               start: int,
                               end: int) -> int:
    """
    Iterate across all of a user's logins and logouts to calculate
    the total amount of time that they've spent logged in between two times
    """
    pass



import pandas as pd

from . import data_aggregation
from . import data_collection
from . import importing 
from . import reports


class DataHandler:
    """ The main part of this package - an object to handle all the data. """
    def __init__(self):
        pass

    def load_csv(self, csv_path: str):
        pass

    def load_json(self, json_path: str):
        pass

    def load_data_path(self, path: str):
        filetype = path.split(".")[-1]

        if filetype == "csv":
            self.data = self.load_csv(path)
        elif filetype == "json":
            self.data = self.load_json(path)



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name = "ggLeapAnalyticsTools",
    version = "0.0.3",
    author = "Joshua \"Phosphorescent\" Mankelow",
    description = "A python package for helping users to generate and interact with data from ggLeap esports venue management software.",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/Phosphorescentt/ggLeapAnalyticsTools",
    project_urls = {
        "Bug Tracker": "https://github.com/Phosphorescentt/ggLeapAnalyticsTools/issues",
        },
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        "Operating System :: OS Independent",
        ],
    package_dir = {"": "src"}, 
    packages = setuptools.find_packages(where="src"),
    python_requires = ">=3.6",
)
